@@ -7,7 +7,12 @@
 # Created Date: 23.08.2022
 # ---------------------------------------------------------------------------
 
-version = '0.1.4'
+import glob
+from os.path import basename, dirname, isfile, join
+
+import msaSDK.jpui.justpy as justpy
+
+version = "0.1.6"
 __author__ = "Stefan Welcker"
 __copyright__ = "Copyright 2022, U2D.ai"
 __license__ = "MIT"
@@ -15,9 +20,12 @@ __version__ = version
 __maintainer__ = "Stefan Welcker"
 __email__ = "stefan@u2d,.ai"
 __status__ = "Beta"
-__url__ = "https://github.com/swelcker/U2D_MSA_SDK"
+__url__ = "https://github.com/swelcker/msaSDK"
+
 
-from os.path import dirname, basename, isfile, join
-import glob
 modules = glob.glob(join(dirname(__file__), "*.py"))
-__all__ = [ basename(f)[:-3] for f in modules if isfile(f) and not f.endswith('__init__.py')]
+__all__ = [
+    basename(f)[:-3] for f in modules if isfile(f) and not f.endswith("__init__.py")
+]
+
+# __all__ += ['justpy']
