@@ -7,12 +7,11 @@ from ..backends.base import BaseTokenStore, _TokenDataSchemaT
 
 
 class RedisTokenStore(BaseTokenStore):
-
     def __init__(
-            self,
-            redis: Redis,
-            expire_seconds: Optional[int] = 60 * 60 * 24 * 3,
-            TokenDataSchema: _TokenDataSchemaT = None
+        self,
+        redis: Redis,
+        expire_seconds: Optional[int] = 60 * 60 * 24 * 3,
+        TokenDataSchema: _TokenDataSchemaT = None,
     ):
         super().__init__(expire_seconds, TokenDataSchema)
         self.redis = redis
@@ -24,7 +23,11 @@ class RedisTokenStore(BaseTokenStore):
         return self.TokenDataSchema.parse_raw(data)
 
     async def write_token(self, token_data: Union[_TokenDataSchemaT, dict]) -> str:
-        obj = self.TokenDataSchema.parse_obj(token_data) if isinstance(token_data, dict) else token_data
+        obj = (
+            self.TokenDataSchema.parse_obj(token_data)
+            if isinstance(token_data, dict)
+            else token_data
+        )
         token = secrets.token_urlsafe()
         await self.redis.set(self.get_key(token), obj.json(), ex=self.expire_seconds)
         return token
@@ -33,4 +36,4 @@ class RedisTokenStore(BaseTokenStore):
         await self.redis.delete(self.get_key(token))
 
     def get_key(self, token: str):
-        return f'auth:token:{token}'
+        return f"auth:token:{token}"
