@@ -1,4 +1,4 @@
-from typing import Optional, List
+from typing import List, Optional
 
 from sqlmodel import SQLModel
 
@@ -7,6 +7,7 @@ class MSAOpenAPIInfo(SQLModel):
     """
     **MSAOpenAPIInfo** Pydantic Response Class
     """
+
     name: str = "msaSDK Service"
     """Service Name."""
     version: str = "0.0.0"
@@ -14,4 +15,4 @@ class MSAOpenAPIInfo(SQLModel):
     url: str = "/openapi.json"
     """OpenAPI URL."""
     tags: Optional[List[str]] = None
-    """OpenAPI Tags."""
\ No newline at end of file
+    """OpenAPI Tags."""
