@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-__version__ = '0.1.1'
+__version__ = "0.1.1"
 
 import time
 from threading import Thread
@@ -58,8 +58,9 @@ class MSAHealthCheck(Thread):
                 self.error = e.__str__()
 
             self.healthy = (
-                "positiv:" + str(status_code) if (200 <= status_code < 300) else "negativ:" + str(
-                    status_code)
+                "positiv:" + str(status_code)
+                if (200 <= status_code < 300)
+                else "negativ:" + str(status_code)
             )
 
             time.sleep(self.interval)
