@@ -84,7 +84,11 @@ def init_logging():
     # disable handlers for specific uvicorn loggers
     # to redirect their output to the default uvicorn logger
     # works with uvicorn==0.11.6
-    #print("Logger", [name for name in logging.root.manager.loggerDict])
+    # print("Logger", [name for name in logging.root.manager.loggerDict])
+
+    for handler in logging.root.handlers[:]:
+        logging.root.removeHandler(handler)
+
     loggers = (
         logging.getLogger(name)
         for name in logging.root.manager.loggerDict
@@ -95,11 +99,15 @@ def init_logging():
     intercept_handler = InterceptHandler()
 
     for uvicorn_logger in loggers:
-        uvicorn_logger.handlers = [intercept_handler]
-
-    logging.getLogger("uvicorn").handlers = [intercept_handler]
+        try:
+            uvicorn_logger.handlers = [intercept_handler]
+        except:
+            pass
+    # logging.getLogger().handlers = [intercept_handler]
+    logging.getLogger("uvicorn").handlers = []
+    logging.getLogger("rocketry").handlers = []
 
     # set logs output, level and format
     logger.configure(
-        handlers=[{"sink": sys.stdout, "level": logging.DEBUG, "format": format_record}]
+        handlers=[{"sink": sys.stdout, "level": logging.INFO, "format": format_record}]
     )
